@@ -77,7 +77,7 @@ void QrSink::clickAction(QWidget *parentWindow) {
         addMECARD(barcodeText);
 
     }else if(type==QrSink::Install){
-        openInstallFile(barcodeText);
+        //openInstallFile(barcodeText);
 
     }else if(type==QrSink::URL){
         // make sure our URL starts with http:// and ends at or before a space.
@@ -121,6 +121,7 @@ void QrSink::clickAction(QWidget *parentWindow) {
 
     }else if(type==QrSink::Geo){
         // we don't do anything with this at the moment, so should it be removed?
+        openGeo(barcodeText);
 
     }else if(type==QrSink::YouTube){
     }else if(type==QrSink::Ovi){
@@ -156,13 +157,13 @@ void QrSink::barcodeAnalysed(QString barcodeType, QString barcodeData) {
 
         }else if(barcodeData.indexOf("BIZCARD:",0,Qt::CaseInsensitive)==0){
             type=this->QrSink::BizCard;
-            buttonText.append("Open BizCard");
+            buttonText.append("Open BizCard - may work, fingers crossed");
             barcodeText=barcodeData;
             barcodeInformativeText = barcodeData; // todo, parse and add name of person here
 
         }else if(barcodeData.indexOf("[install]",0,Qt::CaseInsensitive)==0){
             type=this->QrSink::Install;
-            buttonText.append("Install package");
+            buttonText.append("Install package - not working currently");
             barcodeText=barcodeData;
             barcodeInformativeText = barcodeData; // todo, parse and add name of app here
 
@@ -186,7 +187,7 @@ void QrSink::barcodeAnalysed(QString barcodeType, QString barcodeData) {
 
         }else if(barcodeData.indexOf("CNTS:",0,Qt::CaseInsensitive)==0){
             type=this->QrSink::iMode;
-            buttonText.append("Open iMode data");
+            buttonText.append("Open iMode data - not working currently");
             barcodeText=barcodeData;
             barcodeInformativeText = barcodeData;
 
@@ -198,19 +199,19 @@ void QrSink::barcodeAnalysed(QString barcodeType, QString barcodeData) {
 
         }else if(barcodeData.indexOf("MATMSG:",0,Qt::CaseInsensitive)==0){
             type=this->QrSink::iMode;
-            buttonText.append("Open iMode data");
+            buttonText.append("Open iMode data - not working currently");
             barcodeText=barcodeData;
             barcodeInformativeText = barcodeData;
 
         }else if(barcodeData.indexOf("MEBKM:",0,Qt::CaseInsensitive)==0){
             type=this->QrSink::iMode;
-            buttonText.append("Open iMode data");
+            buttonText.append("Open iMode data - not working currently");
             barcodeText=barcodeData;
             barcodeInformativeText = barcodeData;
 
         }else if(barcodeData.indexOf("LAPL:",0,Qt::CaseInsensitive)==0){
             type=this->QrSink::iMode;
-            buttonText.append("Open iMode data");
+            buttonText.append("Open iMode data - not working currently");
             barcodeText=barcodeData;
             barcodeInformativeText = barcodeData;
 
@@ -240,13 +241,13 @@ void QrSink::barcodeAnalysed(QString barcodeType, QString barcodeData) {
 
         }else if(barcodeData.indexOf("mms:",0,Qt::CaseInsensitive)==0){
             type=this->QrSink::MMS;
-            buttonText.append("Open MMS");
+            buttonText.append("Open MMS - not working currently");
             barcodeText=barcodeData;
             barcodeInformativeText = barcodeData;
 
         }else if(barcodeData.indexOf("mmsto:",0,Qt::CaseInsensitive)==0){
             type=this->QrSink::MMS;
-            buttonText.append("Open MMS");
+            buttonText.append("Open MMS - not working currently");
             barcodeText=barcodeData;
             barcodeInformativeText = barcodeData;
 
@@ -258,13 +259,13 @@ void QrSink::barcodeAnalysed(QString barcodeType, QString barcodeData) {
 
         }else if(barcodeData.indexOf("youtube:",0,Qt::CaseInsensitive)==0){
             type=this->QrSink::YouTube;
-            buttonText.append("Open YouTube link");
+            buttonText.append("Open YouTube link - not working currently");
             barcodeText=barcodeData;
             barcodeInformativeText = barcodeData;
 
         }else if(barcodeData.indexOf("ovi:",0,Qt::CaseInsensitive)==0){
             type=this->QrSink::Ovi;
-            buttonText.append("Install from Ovi");
+            buttonText.append("Install from Ovi - not working currently");
             barcodeText=barcodeData;
             barcodeInformativeText = barcodeData;
 
@@ -452,6 +453,44 @@ void QrSink::openInstallFile(QString data)
 
 }
 
+// http://geosms.wordpress.com/the-geosms-standard/
+void QrSink::openGeo(QString data)
+{
+    double lat,lon;
+    unsigned int somenumber=0;
+    qDebug() << "In openGeo()";
+
+    // parse the data
+    if(data.contains("geo:", Qt::CaseInsensitive)){
+        int offset = data.indexOf("geo:",0,Qt::CaseInsensitive);
+        QString geo = data.right(data.length()-offset-4); // also chop off the geo:
+        QStringList geoparts = geo.split(QRegExp("[,;]"));
+
+        // first one should be lat, second lon
+        QString temp = geoparts.at(0);
+        lat = temp.toDouble();
+
+        temp = geoparts.at(1);
+        lon = temp.toDouble();
+
+        // the latter parts hold optional altitude, accuracy and coordinate reference scheme data too
+        // but we don't use this atm
+
+        //
+        // DBus call thanks to chem|st @ #maemo
+        //
+        QDBusInterface *interface = new QDBusInterface("com.nokia.Navigation.NokiaMapsProvider","/Provider","com.nokia.Navigation.MapProvider");
+        interface->call("ShowPlaceGeo",lat,lon,somenumber);
+
+        qDebug() << "Just trying to get Maps to open " << lat << "," << lon;
+
+    }else{
+        return;
+    }
+
+
+
+}
 
 
 
@@ -866,6 +905,10 @@ void QrSink::addMECARD(QString user_data)
 
     // should we add a signal/slot pair so that plugins can signal their success/lack thereof to the ui and the user?
 
+    // make the contact compatible
+    newContact = manager->compatibleContact(newContact);
+
+
     /* Save the contact */
     if(manager->saveContact(&newContact)){
         //QMaemo5InformationBox::information (this->parent.parent, QString("Added MECARD"), 1000);
